/*
 * InstantiatedMessage.java
 * Copyright (C) 2007 Lars Frantzen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See the LICENSE file for the full license
 *
 * Created on 14. Januar 2007, 09:52
 *
 */

package info.frantzen.testing.ssmsimulator.ssm;

import info.frantzen.testing.ssmsimulator.types.TypeInstance;
import java.util.Enumeration;
import java.util.Iterator;

/**
 * An instantiated message is a message together with a Valuation of the interaction variables.
 * We called an instantiated message a "stimulus/reaction" in the FATES 04 paper.
 * @author Lars Frantzen
 * @version 0.1
 */
public class InstantiatedMessage {
    
    private Message message;
    private Valuation valuation;
    
    /**
     * Creates a new instance of InstantiatedMessage
     * @param message the message to be instantiated
     * @param valuation the valuation of the interaction variables
     */
    public InstantiatedMessage(Message message, Valuation valuation) {
        this.message = message;
        this.valuation = valuation;
    }
    
    /**
     * Getter for the Message attribute.
     * @return the message attribute
     */
    public Message getMessage() {
        return message;
    }
    
    /**
     * Getter for the Valuation attribute.
     * @return the Valuation
     */
    public Valuation getValuation() {
        return valuation;
    }
    
    public String toString() {
        return message.toString() + '(' + valuation + ')';
    }
    
    
    // This contains a modified version of the toString() from Valuation.java... We display instantiated
    // messages as the test events, so here should appear the WSDL names.
//    public String toWSDLString() {
//        StringBuffer result = new StringBuffer();
//        result.append(message.toString() + '(');
//        
//        for (Enumeration keys = valuation.getValuationTable().keys() ; keys.hasMoreElements() ; ) {
//            String key = (String) keys.nextElement();
//            result.append(varName2WSDLName(key));
//            result.append("(");
//            TypeInstance ti = valuation.getValuationTable().get(key);
//            result.append(ti);
//            result.append(")");
//            if (keys.hasMoreElements())
//                result.append(',');
//        }
//        
//        result.append(')');
//        return result.toString();
//    }
//    
//    private String varName2WSDLName(String key) {
//        for (Iterator it = message.getType().iterator(); it.hasNext() ; ) {
//            InteractionVariable iv = (InteractionVariable) it.next();
//            if (iv.getName().equals(key))
//                return iv.getWSDLName();
//        }
//        return null;
//    }
    
}
