/*
 * Port.java
 * Copyright (C) 2007 Lars Frantzen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See the LICENSE file for the full license
 *
 * Created on December 13, 2006, 5:58 PM
 *
 */

package info.frantzen.testing.ssmsimulator.ssm;

/**
 * A port at which operations take place.
 * @author Lars Frantzen
 * @version 0.1
 */
public class Port {
    
    private String name;
    private InstantiatedMessage myQuiescence;
    
    /**
     * Creates a new instance of Port.
     * @param name the name of the port
     */
    public Port(String name) {
        this.name = name;
        myQuiescence = new InstantiatedMessage(Message.generateQuiescenceMessage(this),null);
    }
    
    /**
     * Getter for the name attribute.
     * @return the name of the Port
     */
    public String getName() {
        return name;
    }
    
    public InstantiatedMessage getMyQuiescence() {
        return myQuiescence;
    }
    
    /**
     * A String representation of the Port.
     * @return a String representation of the Port
     */
    public String toString() {
        return "Port " + name;
    }
    
    /**
     * Checks the consistency, i.e. the name is not the empty String.
     * @return true if the consistency is ok, false otherwise
     */
    public boolean checkConsistency() {
        return (name != "");
    }
    
    public boolean equals (Port p) {
        return name == p.getName();
    }
}
