/*
 * Variable.java
 * Copyright (C) 2007 Lars Frantzen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See the LICENSE file for the full license
 *
 * Created on 2. Januar 2007, 15:44
 *
 */

package info.frantzen.testing.ssmsimulator.ssm;

import info.frantzen.testing.ssmsimulator.types.Type;
import info.frantzen.testing.ssmsimulator.types.TypeInstance;

/**
 * An abstract class for variables. Concrete variables are either {@link LocationVariable location variables}
 * or {@link InteractionVariable interaction variables}.
 * @author Lars Frantzen
 * @version 0.2
 */
public abstract class Variable {
    
    private String name;
    private Type type;
    private TypeInstance instance = null;
    
    /**
     * Creates a new instance of Variable.
     * @param name the name of the variable
     * @param type the type of the variable
     * @param value the value of the variable
     */
    public Variable(String name, Type type, TypeInstance value) {
        this.name = name;
        this.type = type;
        this.instance = value;
    }
    
    /**
     * Creates a new instance of Variable without a specific value, i.e. the variable
     * is not initialised.
     * @param name the name of the variable
     * @param type the type of the variable
     */
    public Variable(String name, Type type) {
        this.name = name;
        this.type = type;
    }
    
    /**
     * Getter for the name.
     * @return the name of the variable
     */
    public String getName() {
        return name;
    }
    
    /**
     * Getter for the type.
     * @return the type of the variable
     */
    public Type getType() {
        return type;
    }
    
    /**
     * Getter for the value of the variable (i.e. a type instance).
     * @return the value of the variable (i.e. a type instance)
     */
    public TypeInstance getInstance() {
        return instance;
    }
    
    /**
     * Setter for the value of the variable (i.e. a type instance).
     * @param instance the new value of the variable (i.e. a type instance)
     */
    public void setInstance(TypeInstance instance) {
        this.instance = instance;
    }
    
    /**
     * Checks the consistency, i.e. the name is not the empty string and the type is not null.
     * @return true if the consistency is ok, false otherwise
     */
    public boolean checkConsistency() {
//        if (this instanceof LocationVariable)
//            return ((name != "") && (type != null) && (instance != null));
//        else
//            return ((name != "") && (type != null) && (instance == null));
    return ((name != "") && (type != null));
    }
    
    /**
     * A string representation of the Variable.
     * @return a string representation of the Variable
     */
    public String toString() {
        StringBuffer sb = new StringBuffer();
        sb.append(name + ':' + type);
        if (this instanceof InteractionVariable)
            sb.append(" (Interaction Variable)");
        else
            sb.append(" (Location Variable)");
        return sb.toString();
    }
}
