/*
 * EnumerationInstance.java
 * Copyright (C) 2007 Lars Frantzen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See the LICENSE file for the full license
 *
 * Created on 30. Dezember 2006, 14:49
 *
 */

package info.frantzen.testing.ssmsimulator.types;

/**
 * An enumeration instance is an instance of an {@link Enumeration enumeration}, i.e.
 * a (string) element. Additionally we store a reference to the correspondong
 * {@link Enumeration enumeration}. This is necessary to compare two enumeration
 * instances by the interpreter.
 * @author Lars Frantzen
 * @version 0.1
 */
public class EnumerationInstance extends TypeInstance {
    
    Enumeration enu;
    
    /**
     * Creates a new instance of EnumerationInstance.
     * @param enu the corresponding enumeration
     * @param value the string element of the enumeration
     */
    public EnumerationInstance(Enumeration enu, String value) {
        super(value);
        this.enu = enu;
    }
    
    /**
     * A string representation of the enumeration instance.
     * @return a string representation of the enumeration instance
     */
    public String toString() {
        return (String) getValue() + "@" +  enu.getName();
    }
    
    /**
     * Getter for the corresponding enumeration.
     * @return the corresponding enumeration
     */
    public Enumeration getEnumeration() {
        return enu;
    }

    /**
     * Clones this enumeration instance.
     * @return the cloned enumeration instance
     */
    public EnumerationInstance clone() {
        return new EnumerationInstance(enu, (String) getValue());
    }
}
