/*
 * ST_Int.java
 * Copyright (C) 2007 Lars Frantzen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See the LICENSE file for the full license
 *
 * Created on 30. Dezember 2006, 13:30
 *
 */

package info.frantzen.testing.ssmsimulator.types;

import javax.xml.namespace.QName;

/**
 * The (simple) Integer type.
 * @author Lars Frantzen
 * @version 0.3
 */
public class ST_Int extends SimpleType {
    
    /**
     * Creates a new instance of ST_Int.
     */
    public ST_Int() {
        super(new QName("ST_Int"), "Integer");
    }
    
    /**
     * Returns a random {@link ST_IntInstance ST_Int instance}.
     * @return a random ST_Int instance
     */
    public ST_IntInstance generateRandomInstance() {
        return new ST_IntInstance(new Integer(random.nextInt()));
    }
    
    /**
     * Returns the next boundary {@link ST_IntInstance ST_Int instance}.<br>
     * <B>Warning: </B>not yet implemented correctly!
     * @return the next boundary ST_Int instance
     */
    public ST_IntInstance generateNextBoundaryInstance() {
        // TODO
        return new ST_IntInstance(new Integer(42));
    }
    
    /**
     * Returns the number of boundary {@link ST_IntInstance ST_Int instances}.<br>
     * <B>Warning: </B>not yet implemented correctly!
     * @return the number of boundary ST_Int instances
     */
    public int numberOfBoundaryInstances() {
        // TODO
        return 42;
    }
    
    /**
     * Returns the initial {@link ST_IntInstance ST_Int instance}, i.e. 0.
     * @return the initial ST_Int instance, i.e. 0
     */
    public ST_IntInstance generateInitialInstance() {
        return new ST_IntInstance(new Integer(0));
    }
    
    /**
     * Returns true for all Integere objects since this simple type is not restricted.
     * @param o the object for which the restriction shall be verified
     * @return true for all Integer instances
     */
    public boolean checkRestriction(Object o) {
        if (o instanceof Integer)
            return true;
        else
            return false;
    }
    
    /**
     * A string representation of the type.
     * @return a string representation of the type
     */
    public String toString() {
        return "ST_Int";
    }
    
    
    
}
