/*
 * ST_PosInt.java
 * Copyright (C) 2007 Lars Frantzen
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * See the LICENSE file for the full license
 *
 * Created on 30. Dezember 2006, 13:30
 *
 */

package info.frantzen.testing.ssmsimulator.types;

import info.frantzen.testing.ssmsimulator.TreeSolverInterface;
import javax.xml.namespace.QName;

/**
 * The (simple) Integer type with a restriction on non-negative values.
 * @author Lars Frantzen
 * @version 0.3
 */
public class ST_PosInt extends SimpleType {
    
    /**
     * Creates a new instance of ST_Int.
     */
    public ST_PosInt() {
        super(new QName("ST_PosInt"), "Integer");
    }
    
    /**
     * Returns a random {@link ST_PosIntInstance ST_PosInt instance}.
     * @return a random ST_PosInt instance
     */
    public ST_PosIntInstance generateRandomInstance() {
        return new ST_PosIntInstance(new Integer(Math.abs(random.nextInt(TreeSolverInterface.MAXINTRANDOM))));
    }
    
    /**
     * Returns the next boundary {@link ST_PosIntInstance ST_PosInt instance}.<br>
     * <B>Warning: </B>not yet implemented correctly!
     * @return the next boundary ST_PosInt instance
     */
    public ST_PosIntInstance generateNextBoundaryInstance() {
        // TODO
        return new ST_PosIntInstance(new Integer(42));
    }
    
    /**
     * Returns the initial {@link ST_PosIntInstance ST_PosInt instance}, i.e. 0.
     * @return the initial ST_PosInt instance, i.e. 0
     */
    public ST_PosIntInstance generateInitialInstance() {
        return new ST_PosIntInstance(new Integer(0));
    }
    
    /**
     * Returns the number of boundary {@link ST_PosIntInstance ST_PosInt instances}.<br>
     * <B>Warning: </B>not yet implemented correctly!
     * @return the number of boundary ST_PosInt instances
     */
    public int numberOfBoundaryInstances() {
        // TODO
        return 42;
    }
    
    /**
     * Returns true for all Integer instances with a value >= 0.
     * @param o the object for which the restriction shall be verified
     * @return true for all Integer instances with a value >= 0, false otherwise
     */
    public boolean checkRestriction(Object o) {
        if (o instanceof Integer)
            return ((Integer) o) >= 0;
        else
            return false;
    }
    
    /**
     * A string representation of the type.
     * @return a string representation of the type
     */
    public String toString() {
        return "ST_PosInt";
    }
    
     
    
}
